@@ -104,7 +104,11 @@ protected:
 //    bool x11Event(XEvent * e);
     virtual bool processOtherEvents(xcb_generic_event_t* e);
     virtual bool processXkbEvents(xcb_generic_event_t* e);
-    virtual bool nativeEventFilter(const QByteArray &eventType, void *message, long *) Q_DECL_OVERRIDE;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
+#else
+    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
+#endif
 
 private:
     int registerForXkbEvents(Display* display);
